# Table of Contents
* [Action Statements](#action-statements)
    * [SELL](#sell-statement)
    * [BUY](#buy-statement)
* [Functions](#functions)
    * [PURCHASING_POWER](#purchasing_power)
    * [CURRENT_PRICE](#current_price)


# Action Statements

## SELL Statement
```
[SELL] [Units] OF [Product]
    FOR [Amount]
    FROM [Exchange]
    WITH LIMIT OF [Units]
AND
[Other Action Statements]
    FOR EVERY
        [Units] OF [Product] [SOLD]
            FROM [Exchange]/ANYWHERE
        AND/OR
        [Units] OF [Product] [BOUGHT]
            FROM [Exchange]/ANYWHERE
AS 'ACTION_NAME'
```

### Examples

#### Simple Sell
```
SELL 1 SHARES OF QQQ FROM "MyBrokerAccount"
```

#### Sell Trigger
```
SELL 1 SHARES OF QQQ
  FOR 10 USD
  FROM "MyBrokerAccount"
  WITH LIMIT OF 100 SHARES
  FOR EVERY
    2 SHARES OF QQQ_TOKEN SOLD
        FROM "CoinBase"
AS 'My Hedge Trigger'
```

## BUY Statement
```
[BUY] [Units] OF [Product]
    FOR [Amount]
    FROM [Exchange]
    WITH LIMIT OF [Units]
AND
[Other Action Statements]
    FOR EVERY
        [Units] OF [Product] [SOLD]
            FROM [Exchange]/ANYWHERE
        AND/OR
        [Units] OF [Product] [BOUGHT]
            FROM [Exchange]/ANYWHERE
```

### Examples
```
BUY 1 SHARES OF BTC_ETF
  FOR 10 USD
  FROM "MyBrokerAccount"
  WITH LIMIT OF PURCHASING_POWER( "MyBrokerAccount", "QQQ" )
  FOR EVERY
    1 BTC OF USD_BTC SOLD
        FROM "CoinBase"
```

# functions

## PURCHASING_POWER

`PURCHASING_POWER( Exchange, Product )`

Returns the maximum [Units] of [Product] can purchase from [Exchange]

## CURRENT_PRICE

`CURRENT_PRICE( Exchange, Product )`

Returns the current price of a product from exchange

# Examples

## Creating a spread

* Max position: $1000
* Spread: $10
* QQQ etf price(Qetf): $100

| Bid             | Ask            |
|-----------------|----------------|
| 10shares@$95    | 10shares@$105  |
| ($1000 of Qetf) | ($800 of Qetf) |

If a trader hit ur ASK by bidding 2 shares of QQQ token

| Bid             | Ask            |
|-----------------|----------------|
| 10shares@$95    | 8shares@$105   |
| ($1000 of Qetf) | ($800 of Qetf) |

If another trader hit ur ASK with a 20 shares of bid, then only 8 shares of his order can be filled. 
* No need to handle his remaining 12 shares , its not ur responsibility, its his "broker/app/program" to deal with unfilled order.

| Bid             | Ask            |
|-----------------|----------------|
| 10shares@$95    |                |
| ($1000 of Qetf) |                |


### SELL Order
```
SELL 10 SHARES OF "QQQ_TOKEN"
    FOR CURRENT_PRICE( "CryptoExchange", "QQQ_TOKEN" ) + 5 USD
    WITH LIMIT OF 1000 USD
    FROM "CryptoExchange"
```


### BUY Order
```
BUY 10 SHARES OF "QQQ_TOKEN"
    FOR CURRENT_PRICE( "CryptoExchange", "QQQ_TOKEN" ) - 5 USD
    WITH LIMIT OF 1000 USD
    FROM "CryptoExchange"
```

### BUY Trigger for above
```
BUY 1 SHARES OF "QQQ"
    FOR CURRENT_PRICE( "StockExchange", "QQQ" )
    FROM "StockExchange"
    FOR EVERY 1 SHARES OF "QQQ_TOKEN" SOLD FROM "CryptoExchange"
```


```
[In reply to Penguin]
#Code example:
"""
set the maximum amount($USD) of QQQ tokens i can sell to traders as [my max position]
"""
set [my max position$]=[$1000]

"""set the amount($USD) of sold QQQ token as $0 becoz i havent sold any QQQ tokens before i start my bot
"""
set [total$].[sold QQQ token] =0

"""
The quantity of the sell order quote i can send to the market is the remaining amount of [my max position], which is [max]-[total].[sold]
initially, 
[my max position$]=$1000,
[total$].[sold QQQ token]=0,
remaining token=
[my max position$] - [total$].[sold QQQ token]=$1000-0=$1000
so,
[remain$]
=[my max position$] - [total$].[sold QQQ token]
"""

#get price quote from the nasdaq
[get][QQQ etf price$] from [ib]

while [total$].[sold QQQ token]
<[my max position$] 
   """find my remaining amount($USD)
   of qqq tokens i can sell
   """
   [remain$]=
   [my max position$]  -  [total$].[sold
   QQQ token]

   """convert the remaining
   amount($USD) to number of shares
   of qqq tokens i can sell
   """
   [share].[remain$]=
   [remain$] / [QQQ etf $price] 
   
#set my Bid Ask spread
   [price].[Bid]=
   [QQQ etf $price]  -  [spread]/2
   [price].[Ask]=
   [QQQ etf $price]  +  [spread]/2
```
